@@ -37,7 +37,7 @@ class AKONADI_MIME_EXPORT MarkAsCommand : public CommandBase
 public:
     MarkAsCommand(const Akonadi::MessageStatus &targetStatus, const Akonadi::Item::List &msgList, bool invert = false, QObject *parent = nullptr);
     MarkAsCommand(const Akonadi::MessageStatus &targetStatus, const Akonadi::Collection::List &folders, bool invert = false, bool recursive = false, QObject *parent = nullptr);
-    ~MarkAsCommand();
+    ~MarkAsCommand() override;
     void execute() override;
 
 private Q_SLOTS:
